==> huaweicloudsdkcodehub-3.1.127-py2.py3-none-any.whl: huaweicloudsdkcodehub/v4/model/list_trusted_ip_addresses_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListTrustedIpAddressesRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'int',
        'offset': 'int',
        'limit': 'int'
    }

    attribute_map = {
        'id': 'id',
        'offset': 'offset',
        'limit': 'limit'
    }

    def __init__(self, id=None, offset=None, limit=None):
        """ListTrustedIpAddressesRequest

        The model defined in huaweicloud sdk

        :param id: 仓库id
        :type id: int
        :param offset: 偏移量
        :type offset: int
        :param limit: 返回数量
        :type limit: int
        """
        
        

        self._id = None
        self._offset = None
        self._limit = None
        self.discriminator = None

        self.id = id
        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit

    @property
    def id(self):
        """Gets the id of this ListTrustedIpAddressesRequest.

        仓库id

        :return: The id of this ListTrustedIpAddressesRequest.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ListTrustedIpAddressesRequest.

        仓库id

        :param id: The id of this ListTrustedIpAddressesRequest.
        :type id: int
        """
        self._id = id

    @property
    def offset(self):
        """Gets the offset of this ListTrustedIpAddressesRequest.

        偏移量

        :return: The offset of this ListTrustedIpAddressesRequest.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this ListTrustedIpAddressesRequest.

        偏移量

        :param offset: The offset of this ListTrustedIpAddressesRequest.
        :type offset: int
        """
        self._offset = offset

    @property
    def limit(self):
        """Gets the limit of this ListTrustedIpAddressesRequest.

        返回数量

        :return: The limit of this ListTrustedIpAddressesRequest.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this ListTrustedIpAddressesRequest.

        返回数量

        :param limit: The limit of this ListTrustedIpAddressesRequest.
        :type limit: int
        """
        self._limit = limit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListTrustedIpAddressesRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcodehub-3.1.152-py2.py3-none-any.whl: huaweicloudsdkcodehub/v4/model/list_trusted_ip_addresses_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListTrustedIpAddressesRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'int',
        'offset': 'int',
        'limit': 'int'
    }

    attribute_map = {
        'id': 'id',
        'offset': 'offset',
        'limit': 'limit'
    }

    def __init__(self, id=None, offset=None, limit=None):
        r"""ListTrustedIpAddressesRequest

        The model defined in huaweicloud sdk

        :param id: 仓库id
        :type id: int
        :param offset: 偏移量
        :type offset: int
        :param limit: 返回数量
        :type limit: int
        """
        
        

        self._id = None
        self._offset = None
        self._limit = None
        self.discriminator = None

        self.id = id
        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit

    @property
    def id(self):
        r"""Gets the id of this ListTrustedIpAddressesRequest.

        仓库id

        :return: The id of this ListTrustedIpAddressesRequest.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        r"""Sets the id of this ListTrustedIpAddressesRequest.

        仓库id

        :param id: The id of this ListTrustedIpAddressesRequest.
        :type id: int
        """
        self._id = id

    @property
    def offset(self):
        r"""Gets the offset of this ListTrustedIpAddressesRequest.

        偏移量

        :return: The offset of this ListTrustedIpAddressesRequest.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        r"""Sets the offset of this ListTrustedIpAddressesRequest.

        偏移量

        :param offset: The offset of this ListTrustedIpAddressesRequest.
        :type offset: int
        """
        self._offset = offset

    @property
    def limit(self):
        r"""Gets the limit of this ListTrustedIpAddressesRequest.

        返回数量

        :return: The limit of this ListTrustedIpAddressesRequest.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        r"""Sets the limit of this ListTrustedIpAddressesRequest.

        返回数量

        :param limit: The limit of this ListTrustedIpAddressesRequest.
        :type limit: int
        """
        self._limit = limit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListTrustedIpAddressesRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
